/**
 * 移动电话号码验证
 * @param str
 * @returns {boolean}
 */
export function isMobile (str) {
  const mobile = /^(((13[0-9]{1})|(15[0-9]{1})|(16[0-9]{1})|(18[0-9]{1})|(17[0-9]{1})|(19[0-9]{1}))+\d{8})$/
  return mobile.test(str)
}

/**
 * 固定电话号码验证
 * @param str
 * @returns {boolean}
 */
export function isPhone (str) {
  const phone = /(^(\d{3,4}-)?\d{6,8}$)|(^(\d{3,4}-)?\d{6,8}(-\d{1,5})?$)|(\d{6,20})/
  return phone.test(str)
}

/**
 * 开户行账号验证
 * 开户行账号只能为数字、长度限定为25
 * @param str
 * @returns {boolean}
 */
export function isBankNumber (str) {
  const bankNumber = /^[0-9]\d{24}$/
  return bankNumber.test(str)
}

/**
 * 联系人联系方式验证
 * 联系人联系方式只能为数字，长度限定为20
 * @param str
 * @returns {boolean}
 */
export function isLinkMobile (str) {
  const linkMobile = /^[0-9]\d{19}$/
  return linkMobile.test(str)
}

export default {isMobile, isPhone, isBankNumber, isLinkMobile}
